
// BANNER START
const require = (await import("node:module")).createRequire(import.meta.url);
const __filename = (await import("node:url")).fileURLToPath(import.meta.url);
const __dirname = (await import("node:path")).dirname(__filename);
// BANNER END
    

// src/index.ts
import { addNormalScript, babelParse, generateTransform, getLang, MagicString, parseSFC } from "@vue-macros/common";
import { createUnplugin } from "unplugin";
var src_default = createUnplugin((options) => ({
  name: "unplugin-vue-router-extend",
  enforce: "pre",
  transform(code, id) {
    var _a;
    const name = (_a = options.routeMap.get(id)) == null ? void 0 : _a.name;
    if (!name)
      return;
    const lang = getLang(id);
    const s = new MagicString(code);
    if (lang === "vue") {
      const sfc = parseSFC(code, id);
      if (sfc.script) {
        const offset = sfc.script.loc.start.offset;
        transformAST(sfc.getScriptAst(), name, s, offset);
      } else {
        const normalScript = addNormalScript(sfc, s);
        const scriptOffset = normalScript.start();
        s.appendLeft(
          scriptOffset,
          `
import { defineComponent } from 'vue'
export default /* @__PURE__ */ defineComponent({
  name: '${name}'
})`
        );
        normalScript.end();
      }
    } else if (/[jt]sx?$/.test(lang)) {
      const ast = babelParse(code, lang);
      transformAST(ast, name, s);
    }
    return generateTransform(s, id);
  }
}));
function transformAST(ast, name, s, offset = 0) {
  var _a, _b;
  for (const stmt of ast.body) {
    if (stmt.type === "ExportDefaultDeclaration" && stmt.declaration.type === "CallExpression" && stmt.declaration.callee.type === "Identifier" && stmt.declaration.callee.name === "defineComponent") {
      const argument = stmt.declaration.arguments.find((i) => i.type === "ObjectExpression");
      if (argument) {
        if (!((_a = argument.properties) == null ? void 0 : _a.find(
          (prop) => prop.type === "ObjectProperty" && prop.key.type === "Identifier" && prop.key.name === "name"
        ))) {
          s.appendLeft(
            offset + argument.end - 1,
            `${!((_b = argument.extra) == null ? void 0 : _b.trailingComma) && argument.properties.length ? "," : ""} name: '${name}'`
          );
        }
      } else {
        s.appendRight(offset + stmt.declaration.end - 1, `, { name: '${name}' }`);
      }
    }
  }
}

export {
  src_default
};
